==> qshare-2.1.1-i486-1sl.txz: usr/share/qshare/i18n/qshare_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en">
<context>
    <name>About</name>
    <message>
        <location filename="../src/about.ui" line="20"/>
        <source>About qShare</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="70"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="77"/>
        <location filename="../src/about.cpp" line="57"/>
        <source>qrc:/docs/qshare.html</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="86"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="93"/>
        <source>qrc:/docs/gpl.html</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="102"/>
        <source>Credits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="109"/>
        <location filename="../src/about.cpp" line="58"/>
        <source>qrc:/docs/credits.html</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <location filename="../src/config.ui" line="14"/>
        <source>qShare config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="32"/>
        <source>Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="101"/>
        <source>Show hidden files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="118"/>
        <source>Read-only anonymous access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="140"/>
        <source>Sharing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="146"/>
        <source>Shared folders:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="163"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="168"/>
        <source>Write access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="173"/>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="183"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="194"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="212"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="218"/>
        <source>Available translations:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="229"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="235"/>
        <source>show splash on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="242"/>
        <source>Use customized to open remote folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="254"/>
        <source>firefox &quot;%U&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="261"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="41"/>
        <source>Anonymous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="71"/>
        <source>login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="91"/>
        <source>password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="61"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="81"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="262"/>
        <source>new folder #</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="268"/>
        <location filename="../src/config.cpp" line="309"/>
        <location filename="../src/config.cpp" line="369"/>
        <source>forbidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="309"/>
        <location filename="../src/config.cpp" line="369"/>
        <source>allowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="333"/>
        <source>Select a folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="392"/>
        <source>french</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="393"/>
        <source>english</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="394"/>
        <source>spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="395"/>
        <source>russian</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <source>qShare</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="25"/>
        <source>Available computers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="37"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="48"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="71"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="79"/>
        <source>&amp;Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="86"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="93"/>
        <source>&amp;Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="108"/>
        <source>&amp;Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="117"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="126"/>
        <source>&amp;About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="135"/>
        <source>&amp;Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="144"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="153"/>
        <source>&amp;Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="162"/>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchFile</name>
    <message>
        <location filename="../src/searchfile.ui" line="14"/>
        <source>Find files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.ui" line="26"/>
        <source>Expression:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.ui" line="36"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.ui" line="47"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.ui" line="73"/>
        <source>computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.ui" line="78"/>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.ui" line="101"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Stats</name>
    <message>
        <location filename="../src/stats.ui" line="14"/>
        <location filename="../src/stats.ui" line="77"/>
        <source>Stats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="32"/>
        <location filename="../src/stats.ui" line="121"/>
        <source>Connections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="54"/>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="59"/>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="64"/>
        <source>Activity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="111"/>
        <source>Total sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="116"/>
        <source>Total received</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="126"/>
        <source>Max connections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="131"/>
        <source>Total connections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.cpp" line="104"/>
        <location filename="../src/stats.cpp" line="118"/>
        <source>Bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.cpp" line="106"/>
        <location filename="../src/stats.cpp" line="120"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.cpp" line="108"/>
        <location filename="../src/stats.cpp" line="122"/>
        <source>MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.cpp" line="110"/>
        <location filename="../src/stats.cpp" line="124"/>
        <source>GB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.cpp" line="112"/>
        <location filename="../src/stats.cpp" line="126"/>
        <source>TB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../src/trayicon.cpp" line="27"/>
        <source>qShare started</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="27"/>
        <source>qShare is up and running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="45"/>
        <source>computers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="47"/>
        <source>&amp;Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="48"/>
        <source>&amp;Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="49"/>
        <source>&amp;Stats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="50"/>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="53"/>
        <source>&amp;Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="59"/>
        <location filename="../src/trayicon.cpp" line="92"/>
        <location filename="../src/trayicon.cpp" line="94"/>
        <source>qShare</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="90"/>
        <source>refresh list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qshare-2.1.3-i486-1sl.txz: usr/share/qshare/i18n/qshare_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en">
<context>
    <name>About</name>
    <message>
        <location filename="../src/about.ui" line="20"/>
        <source>About qShare</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="70"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="77"/>
        <location filename="../src/about.cpp" line="57"/>
        <source>qrc:/docs/qshare.html</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="86"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="93"/>
        <source>qrc:/docs/gpl.html</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="102"/>
        <source>Credits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="109"/>
        <location filename="../src/about.cpp" line="58"/>
        <source>qrc:/docs/credits.html</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <location filename="../src/config.ui" line="14"/>
        <source>qShare config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="32"/>
        <source>Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="101"/>
        <source>Show hidden files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="118"/>
        <source>Read-only anonymous access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="140"/>
        <source>Sharing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="146"/>
        <source>Shared folders:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="163"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="168"/>
        <source>Write access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="173"/>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="183"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="194"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="212"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="218"/>
        <source>Available translations:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="229"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="235"/>
        <source>show splash on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="242"/>
        <source>Use customized to open remote folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="254"/>
        <source>firefox &quot;%U&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="261"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="41"/>
        <source>Anonymous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="71"/>
        <source>login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="91"/>
        <source>password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="61"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.ui" line="81"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="66"/>
        <location filename="../src/config.cpp" line="105"/>
        <source>on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="273"/>
        <source>new folder #</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="279"/>
        <location filename="../src/config.cpp" line="320"/>
        <location filename="../src/config.cpp" line="380"/>
        <source>forbidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="320"/>
        <location filename="../src/config.cpp" line="380"/>
        <source>allowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="344"/>
        <source>Select a folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="447"/>
        <source>french</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="446"/>
        <source>english</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="448"/>
        <source>polish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="450"/>
        <source>spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config.cpp" line="449"/>
        <source>russian</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <source>qShare</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="25"/>
        <source>Available computers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="37"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="48"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="71"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="79"/>
        <source>&amp;Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="86"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="93"/>
        <source>&amp;Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="108"/>
        <source>&amp;Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="117"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="126"/>
        <source>&amp;About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="135"/>
        <source>&amp;Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="144"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="153"/>
        <source>&amp;Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="162"/>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="50"/>
        <location filename="../src/mainwindow.cpp" line="100"/>
        <source>on</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchFile</name>
    <message>
        <location filename="../src/searchfile.ui" line="14"/>
        <source>Find files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.ui" line="26"/>
        <source>Expression:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.ui" line="36"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.ui" line="47"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.ui" line="73"/>
        <source>computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.ui" line="78"/>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.ui" line="101"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/searchfile.cpp" line="45"/>
        <location filename="../src/searchfile.cpp" line="66"/>
        <source>from</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Stats</name>
    <message>
        <location filename="../src/stats.ui" line="14"/>
        <location filename="../src/stats.ui" line="77"/>
        <source>Stats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="32"/>
        <location filename="../src/stats.ui" line="121"/>
        <source>Connections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="54"/>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="59"/>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="64"/>
        <source>Activity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="111"/>
        <source>Total sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="116"/>
        <source>Total received</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="126"/>
        <source>Max connections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.ui" line="131"/>
        <source>Total connections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.cpp" line="107"/>
        <location filename="../src/stats.cpp" line="121"/>
        <source>Bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.cpp" line="109"/>
        <location filename="../src/stats.cpp" line="123"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.cpp" line="111"/>
        <location filename="../src/stats.cpp" line="125"/>
        <source>MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.cpp" line="113"/>
        <location filename="../src/stats.cpp" line="127"/>
        <source>GB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/stats.cpp" line="115"/>
        <location filename="../src/stats.cpp" line="129"/>
        <source>TB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../src/trayicon.cpp" line="27"/>
        <source>qShare started</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="27"/>
        <source>qShare is up and running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="45"/>
        <source>computers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="47"/>
        <source>&amp;Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="48"/>
        <source>&amp;Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="49"/>
        <source>&amp;Stats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="50"/>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="53"/>
        <source>&amp;Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="59"/>
        <location filename="../src/trayicon.cpp" line="92"/>
        <location filename="../src/trayicon.cpp" line="94"/>
        <source>qShare</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="90"/>
        <source>refresh list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/trayicon.cpp" line="92"/>
        <location filename="../src/trayicon.cpp" line="94"/>
        <source>on</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
